@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.56.2.1 2005/07/08 21:15:43 chpe Exp $
+ *  $Id: ephy-history.c,v 1.59 2005/07/08 21:15:19 chpe Exp $
  */
 
 #include "config.h"
@@ -208,8 +208,8 @@ ephy_history_class_init (EphyHistoryClass *klass)
                               ephy_marshal_VOID__STRING_STRING,
                               G_TYPE_NONE,
                               2,
-			      G_TYPE_STRING,
-			      G_TYPE_STRING);
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	g_type_class_add_private (object_class, sizeof (EphyHistoryPrivate));
 }
@@ -256,6 +256,13 @@ remove_obsolete_pages (EphyHistory *eb)
 	}
 }
 
+static gboolean
+save_filter (EphyNode *node,
+	     EphyNode *page_node)
+{
+	return node != page_node;
+}
+
 static void
 ephy_history_save (EphyHistory *eb)
 {
@@ -275,8 +282,8 @@ ephy_history_save (EphyHistory *eb)
 		 EPHY_HISTORY_XML_VERSION,
 		 NULL, /* comment */
 		 eb->priv->hosts,
-		 1, eb->priv->pages,
-		 eb->priv->pages, 0,
+		 (EphyNodeFilterFunc) save_filter, eb->priv->pages,
+		 eb->priv->pages, NULL, NULL,
 		 NULL);
 
 	if (ret >=0)
