@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.109.2.1 2005/03/10 15:51:16 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.114 2005/07/24 21:37:01 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -28,6 +28,7 @@
 #include "ephy-cookie-manager.h"
 #include "ephy-password-manager.h"
 #include "ephy-permission-manager.h"
+#include "ephy-embed-shell.h"
 
 #include "glib.h"
 #include "ephy-debug.h"
@@ -49,9 +50,9 @@
 
 #include <nsCOMPtr.h>
 #include <nsMemory.h>
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 #include <nsIPrefService.h>
 #include <nsIServiceManager.h>
 #include <nsIWindowWatcher.h>
@@ -236,10 +237,17 @@ mozilla_set_default_prefs (MozillaEmbedSingle *mes)
                 g_warning ("failed to read user preferences, error: %x", rv);
         }
 
-	/* FIXME We need to do this because mozilla doesnt set product
-	sub for embedding apps */
+#ifdef HAVE_GECKO_1_8
+	/* FIXME: maybe only set the major version ("1.6", "1.8") here? */
+	pref->SetCharPref ("general.useragent.extra.epiphany", "Epiphany/" VERSION);
+
+	/* Unset old prefs, otherwise they end up in the user agent string too */
+	pref->ClearUserPref ("general.useragent.vendor");
+	pref->ClearUserPref ("general.useragent.vendorSub");
+#else
 	pref->SetCharPref ("general.useragent.vendor", "Epiphany");
 	pref->SetCharPref ("general.useragent.vendorSub", VERSION);
+#endif
 
 	/* Open ftp uris with an external handler if one is setup */
 	pref->SetBoolPref("network.protocol-handler.external.ftp",
@@ -537,6 +545,20 @@ init_services (MozillaEmbedSingle *single)
 	return TRUE;
 }
 
+static void
+prepare_close_cb (EphyEmbedShell *shell)
+{
+	GValue value = { 0, };
+
+	/* To avoid evil web sites posing an alert and thus inhibiting
+	 * shutdown, we just turn off javascript! :)
+	 */
+	g_value_init (&value, G_TYPE_BOOLEAN);
+	g_value_set_boolean (&value, FALSE);
+	mozilla_pref_set ("javascript.enabled", &value);
+	g_value_unset (&value);
+}
+
 static void
 mozilla_embed_single_init (MozillaEmbedSingle *mes)
 {
@@ -564,6 +586,10 @@ mozilla_embed_single_init (MozillaEmbedSingle *mes)
 
 		exit (0);
 	}
+
+	g_signal_connect_object (embed_shell, "prepare-close",
+				 G_CALLBACK (prepare_close_cb), mes,
+				 (GConnectFlags) 0);
 }
 
 static void
@@ -646,12 +672,6 @@ impl_get_offline_mode (EphyEmbedSingle *shell)
 	return isOffline;
 }
 
-static GList *
-impl_get_printer_list (EphyEmbedSingle *shell)
-{
-	return MozillaPrivate::GetPrinterList ();
-}
-
 static GList *
 impl_get_font_list (EphyEmbedSingle *shell,
 		    const char *langGroup)
@@ -1009,7 +1029,6 @@ ephy_embed_single_iface_init (EphyEmbedSingleIface *iface)
 	iface->get_offline_mode = impl_get_offline_mode;
 	iface->get_font_list = impl_get_font_list;
 	iface->open_window = impl_open_window;
-	iface->get_printer_list = impl_get_printer_list;
 }
 
 static void
