@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.c,v 1.50 2005/01/30 20:09:58 chpe Exp $
+ *  $Id: ephy-dialog.c,v 1.51 2005/05/01 19:48:05 chpe Exp $
  */
 
 #include "config.h"
@@ -1096,7 +1096,7 @@ void
 ephy_dialog_add_enum (EphyDialog *dialog,
 		      const char *id,
 		      guint n_items,
-		      const char **items)
+		      const char *const *items)
 {
 	PropertyInfo *info;
 	int i = 0;
