@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.c,v 1.35 2005/02/26 22:01:48 chpe Exp $
+ *  $Id: ephy-gui.c,v 1.37 2005/05/29 14:29:02 jframeau Exp $
  */
 
 #include "config.h"
@@ -193,28 +193,84 @@ ephy_gui_confirm_overwrite_file (GtkWidget *parent,
 				 const char *filename)
 {
 	GtkWidget *dialog;
-	char *display_name, *path;
-	gboolean retval, writable;
+	char *display_name;
+	gboolean retval;
 
 	if (filename == NULL) return FALSE;
 
 	if (!g_file_test (filename, G_FILE_TEST_EXISTS))
 	{
+		char *path = g_path_get_dirname (filename);
+		gboolean writable = access (path, W_OK) == 0;
+
 		/* check if path is writable to */
-		path = g_path_get_dirname (filename);
-		writable = access (path, W_OK) == 0;
+		if (!writable)
+		{
+			dialog = gtk_message_dialog_new (
+					parent ? GTK_WINDOW(parent) : NULL,
+					GTK_DIALOG_DESTROY_WITH_PARENT,
+					GTK_MESSAGE_ERROR,
+					GTK_BUTTONS_CLOSE,
+					_("Directory %s is not writable"), path);
+
+			gtk_message_dialog_format_secondary_text (
+					GTK_MESSAGE_DIALOG (dialog),
+					_("You do not have permission to "
+						"create files in this directory."));
+
+			gtk_window_set_title (GTK_WINDOW (dialog), _("Directory not writable"));
+			gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
+			if (parent != NULL)
+			{
+				gtk_window_group_add_window (
+						ephy_gui_ensure_window_group (GTK_WINDOW (parent)),
+						GTK_WINDOW (dialog));
+			}
+
+			gtk_dialog_run (GTK_DIALOG (dialog));
+
+			gtk_widget_destroy (dialog);		
+		}
+
 		g_free (path);
 
-		/* FIXME put up some UI to inform the user */
 		return writable;
 	}
 
-	/* check if file is writable */
-	/* FIXME put up some UI to inform the user */
-	if (access (filename, W_OK) != 0) return FALSE;
-
 	display_name = g_filename_display_basename (filename);
 
+	/* check if file is writable */
+	if (access (filename, W_OK) != 0)
+	{
+		dialog = gtk_message_dialog_new (
+				parent ? GTK_WINDOW(parent) : NULL,
+				GTK_DIALOG_DESTROY_WITH_PARENT,
+				GTK_MESSAGE_ERROR,
+				GTK_BUTTONS_CLOSE,
+				_("File %s is not writable"), display_name);
+
+		gtk_message_dialog_format_secondary_text (
+				GTK_MESSAGE_DIALOG (dialog),
+				_("You do not have permission to overwrite this file."));
+
+		gtk_window_set_title (GTK_WINDOW (dialog), _("File not writable"));
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+
+		if (parent != NULL)
+		{
+			gtk_window_group_add_window (
+					ephy_gui_ensure_window_group (GTK_WINDOW (parent)),
+					GTK_WINDOW (dialog));
+		}
+
+		gtk_dialog_run (GTK_DIALOG (dialog));
+
+		gtk_widget_destroy (dialog);		
+
+		return FALSE;
+	}
+
 	dialog = gtk_message_dialog_new
 		(parent ? GTK_WINDOW (parent) : NULL,
 		 GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -276,61 +332,10 @@ ephy_gui_help (GtkWindow *parent,
 	}
 }
 
-gboolean
-ephy_gui_select_row_by_key (GtkTreeView *treeview, gint column, guint32 unicode)
-{
-	GtkTreeModel *model;
-	GtkTreeIter iter, last_iter;
-	GtkTreePath *path;
-	GValue value = {0, };
-	char *string;
-	char *event_string;
-	gboolean found = FALSE;
-	char outbuf[6];
-	int length;
-
-	model = gtk_tree_view_get_model (treeview);
-
-	length = g_unichar_to_utf8 (unicode, outbuf);
-	event_string = g_utf8_casefold (outbuf, length);
-
-	if (!gtk_tree_model_get_iter_first (model, &iter))
-	{
-		g_free (event_string);
-		return FALSE;
-	}
-
-	do
-	{
-		last_iter = iter;
-		gtk_tree_model_get_value (model, &iter, column, &value);
-
-		string = g_utf8_casefold (g_value_get_string (&value), -1);
-		g_utf8_strncpy (string, string, 1);
-		found = (g_utf8_collate (string, event_string) == 0);
-
-		g_free (string);
-		g_value_unset (&value);
-	}
-	while (!found && gtk_tree_model_iter_next (model, &iter));
-
-	if (!found)
-	{
-		iter = last_iter;
-	}
-
-	path = gtk_tree_model_get_path (model, &iter);
-	gtk_tree_view_set_cursor (GTK_TREE_VIEW (treeview), path, NULL, FALSE);
-	gtk_tree_path_free (path);
-	g_free (event_string);
-
-	return TRUE;
-}
-
 gboolean
 ephy_gui_is_middle_click (void)
 {
-	gboolean new_tab = FALSE;
+	gboolean is_middle_click = FALSE;
 	GdkEvent *event;
 
 	event = gtk_get_current_event ();
@@ -348,14 +353,14 @@ ephy_gui_is_middle_click (void)
 			if ((button == 1 && ((state & modifiers) == GDK_CONTROL_MASK)) ||
 			    (button == 2))
 			{
-				new_tab = TRUE;
+				is_middle_click = TRUE;
 			}
 		}
 
 		gdk_event_free (event);
 	}
 
-	return new_tab;
+	return is_middle_click;
 }
 
 void
