@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.c,v 1.12 2004/03/27 12:59:24 chpe Exp $
+ *  $Id: ephy-stock-icons.c,v 1.16 2005/01/20 14:45:06 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <gtk/gtk.h>
 #include <glib.h>
@@ -46,13 +44,17 @@ ephy_stock_icons_init (void)
 		STOCK_VIEW_SOURCE,
 		STOCK_SEND_MAIL,
 		STOCK_ADD_BOOKMARK,
-		STOCK_PRINT_SETUP
+		STOCK_PRINT_SETUP,
+		STOCK_LOCK_INSECURE,
+		STOCK_LOCK_SECURE,
+		STOCK_LOCK_BROKEN,
+		STOCK_LEAVE_FULLSCREEN
 	};
 
 	static const GtkStockItem items[] =
 	{
-		{ EPHY_STOCK_SECURE,	N_("Secure"),		0, 0, NULL },
-		{ EPHY_STOCK_UNSECURE,	N_("Insecure"),		0, 0, NULL },
+		{ EPHY_STOCK_CLOSE_TAB,	N_("Close Tab"),	0, 0, NULL },
+		{ EPHY_STOCK_POPUPS,	N_("Popup Windows"),	0, 0, NULL },
 		{ EPHY_STOCK_HISTORY,	N_("History"),		0, 0, NULL },
 		{ EPHY_STOCK_BOOKMARKS, N_("Bookmarks"),	0, 0, NULL },
 		{ EPHY_STOCK_ENTRY,	N_("Address Entry"),	0, 0, NULL },
@@ -93,4 +95,6 @@ ephy_stock_icons_init (void)
 	}
 
 	g_object_unref (G_OBJECT (factory));
+
+	gtk_icon_size_register (EPHY_ICON_SIZE_TAB_BUTTON, 10, 10);
 }
