@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.69 2005/01/28 22:25:02 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.72 2005/07/26 17:41:04 chpe Exp $
  */
 
 #include "config.h"
@@ -50,6 +50,7 @@
 
 #define TOOLITEM_WIDTH_CHARS	24
 #define MENUITEM_WIDTH_CHARS	32
+#define LABEL_WIDTH_CHARS       32
 
 #define EPHY_TOPIC_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOPIC_ACTION, EphyTopicActionPrivate))
 
@@ -160,15 +161,24 @@ menu_deactivate_cb (GtkMenuShell *ms, GtkWidget *button)
 static void
 menu_activate_cb (GtkWidget *item, GtkAction *action)
 {
+	EphyBookmarks *bookmarks;
 	EphyNode *node;
 	const char *location;
+	char *address;
 
 	node = g_object_get_data (G_OBJECT (item), "node");
 	location = ephy_node_get_property_string
 		(node, EPHY_NODE_BMK_PROP_LOCATION);
+	g_return_if_fail (location != NULL);
 
-	ephy_link_open (EPHY_LINK (action), location, NULL,
+	bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
+	address = ephy_bookmarks_resolve_address (bookmarks, location, NULL);
+	g_return_if_fail (address != NULL);
+
+	ephy_link_open (EPHY_LINK (action), address, NULL,
 			ephy_gui_is_middle_click () ? EPHY_LINK_NEW_TAB : 0);
+
+	g_free (address);
 }
 
 static void
@@ -295,8 +305,9 @@ append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node,
 
 			item = gtk_image_menu_item_new_with_label (title);
 			label = (GtkLabel *) ((GtkBin *) item)->child;
-			gtk_label_set_max_width_chars (label, MENUITEM_WIDTH_CHARS);
+			gtk_label_set_max_width_chars (label, LABEL_WIDTH_CHARS);
 			gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_END);
+			gtk_label_set_use_underline (label, FALSE);
 
 			if (icon_location)
 			{
@@ -330,6 +341,7 @@ append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node,
 static void
 open_in_tabs_activate_cb (GtkWidget *item, EphyTopicAction *action)
 {
+	EphyBookmarks *bookmarks;
 	EphyNode *node;
 	GPtrArray *children;
 	EphyTab *tab = NULL;
@@ -348,16 +360,24 @@ open_in_tabs_activate_cb (GtkWidget *item, EphyTopicAction *action)
 
 	node_list = g_list_sort (node_list, (GCompareFunc) sort_bookmarks);
 
+	bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
+
 	for (l = node_list; l != NULL; l = l->next)
 	{
 		EphyNode *child = (EphyNode *) l->data;
-		const char *address;
+		const char *location;
+		char *address;
 
-		address = ephy_node_get_property_string
+		location = ephy_node_get_property_string
 			(child, EPHY_NODE_BMK_PROP_LOCATION);
+		g_return_if_fail (location != NULL);
+
+		address = ephy_bookmarks_resolve_address (bookmarks, location, NULL);
+		g_return_if_fail (address != NULL);
 
 		tab = ephy_link_open (EPHY_LINK (action), address, tab,
 				      tab ? EPHY_LINK_NEW_TAB : EPHY_LINK_NEW_WINDOW);
+		g_free (address);
 	}
 
 	g_list_free (node_list);
@@ -692,8 +712,8 @@ button_toggled_cb (GtkWidget *button,
 		guint event_button = 0;
 
 		menu = build_menu (action);
-		g_signal_connect (menu, "deactivate",
-				  G_CALLBACK (menu_deactivate_cb), button);
+		g_signal_connect_object (menu, "deactivate",
+					 G_CALLBACK (menu_deactivate_cb), button, 0);
 
 		event = gtk_get_current_event ();
 		if (event != NULL)
@@ -909,6 +929,16 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 		g_signal_connect (button, "drag_data_delete",
 				  G_CALLBACK (drag_data_delete_cb), action);
 	}
+	else if (GTK_IS_MENU_ITEM (proxy))
+	{
+		GtkLabel *label;
+
+		label = (GtkLabel *) ((GtkBin *) proxy)->child;
+
+		gtk_label_set_use_underline (label, FALSE);
+		gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_END);
+		gtk_label_set_max_width_chars (label, LABEL_WIDTH_CHARS);
+	}
 }
 
 static void
