@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-action.c,v 1.33 2005/01/13 23:47:32 chpe Exp $
+ *  $Id: ephy-location-action.c,v 1.38 2005/07/26 17:41:04 chpe Exp $
  */
 
 #include "config.h"
@@ -29,10 +29,12 @@
 #include "ephy-link.h"
 #include "ephy-debug.h"
 
+#include <gdk/gdkkeysyms.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtkentrycompletion.h>
+#include <gtk/gtkmain.h>
 
 #define EPHY_LOCATION_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_LOCATION_ACTION, EphyLocationActionPrivate))
 
@@ -41,14 +43,15 @@ struct _EphyLocationActionPrivate
 	EphyWindow *window;
 	GList *actions;
 	char *address;
-	gboolean editable;
+	char *typed_address;
 	EphyNode *smart_bmks;
 	EphyBookmarks *bookmarks;
 	char *icon;
 	EphyFaviconCache *cache;
 	char *lock_stock_id;
 	char *lock_tooltip;
-	gboolean show_lock;
+	guint editable : 1;
+	guint show_lock : 1;
 };
 
 static void ephy_location_action_init       (EphyLocationAction *action);
@@ -72,6 +75,13 @@ enum
 	PROP_WINDOW
 };
 
+enum
+{
+	LOCK_CLICKED,
+	LAST_SIGNAL
+};
+static guint signals[LAST_SIGNAL] = { 0 };
+
 static GObjectClass *parent_class = NULL;
 
 GType
@@ -123,7 +133,7 @@ action_activated_cb (GtkEntryCompletion *completion,
 	                (node, EPHY_NODE_BMK_PROP_LOCATION);
 		g_return_if_fail (smart_url != NULL);
 
-		url = ephy_bookmarks_solve_smart_url
+		url = ephy_bookmarks_resolve_address
 			(action->priv->bookmarks, smart_url, content);
 		g_return_if_fail (url != NULL);
 
@@ -135,16 +145,40 @@ action_activated_cb (GtkEntryCompletion *completion,
 }
 
 static void
-location_url_activate_cb (GtkEntry *entry,
-			  EphyLocationAction *action)
+entry_activate_cb (GtkEntry *entry,
+		   EphyLocationAction *action)
 {
+	EphyBookmarks *bookmarks;
+	GdkEvent *event;
+	gboolean control = FALSE;
 	const char *content;
+	char *address;
 
 	content = gtk_entry_get_text (entry);
-	if (content != NULL)
+	if (content == NULL || content[0] == '\0') return;
+
+	bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
+
+	address = ephy_bookmarks_resolve_address (bookmarks, content, NULL);
+	g_return_if_fail (address != NULL);
+
+	event = gtk_get_current_event ();
+	if (event)
 	{
-		ephy_link_open (EPHY_LINK (action), content, NULL, 0);
+		if (event->type == GDK_KEY_PRESS ||
+		    event->type == GDK_KEY_RELEASE)
+		{
+			control = (event->key.state & gtk_accelerator_get_default_mod_mask ()) == GDK_CONTROL_MASK;
+		}
+			
+		gdk_event_free (event);
 	}
+
+	/* FIXME use ephy_bookmarks_resolve_address here too? */
+	ephy_link_open (EPHY_LINK (action), address, NULL, 
+			control ? EPHY_LINK_NEW_TAB : 0);
+
+	g_free (address);
 }
 
 static void
@@ -154,25 +188,34 @@ user_changed_cb (GtkWidget *proxy, EphyLocationAction *action)
 
 	address = ephy_location_entry_get_location (EPHY_LOCATION_ENTRY (proxy));
 
-	LOG ("user_changed_cb, new address %s", address)
+	LOG ("user_changed_cb, new address %s", address);
 
 	g_signal_handlers_block_by_func (action, G_CALLBACK (sync_address), proxy);
-	ephy_location_action_set_address (action, address);
+	ephy_location_action_set_address (action, address, NULL);
 	g_signal_handlers_unblock_by_func (action, G_CALLBACK (sync_address), proxy);
 }
 
+static void
+lock_clicked_cb (GtkWidget *proxy,
+		 EphyLocationAction *action)
+{
+	g_signal_emit (action, signals[LOCK_CLICKED], 0);
+}
+
 static void
 sync_address (GtkAction *gaction,
 	      GParamSpec *pspec,
 	      GtkWidget *proxy)
 {
 	EphyLocationAction *action = EPHY_LOCATION_ACTION (gaction);
+	EphyLocationActionPrivate *priv = action->priv;
 	EphyLocationEntry *lentry = EPHY_LOCATION_ENTRY (proxy);
 
-	LOG ("sync_address %s", action->priv->address)
+	LOG ("sync_address %s", action->priv->address);
 
 	g_signal_handlers_block_by_func (proxy, G_CALLBACK (user_changed_cb), action);
-	ephy_location_entry_set_location (lentry, action->priv->address);
+	ephy_location_entry_set_location (lentry, priv->address,
+					  priv->typed_address);
 	g_signal_handlers_unblock_by_func (proxy, G_CALLBACK (user_changed_cb), action);
 }
 
@@ -358,10 +401,12 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 
 		entry = ephy_location_entry_get_entry (lentry);
 		g_signal_connect_object (entry, "activate",
-					 G_CALLBACK (location_url_activate_cb),
+					 G_CALLBACK (entry_activate_cb),
 					 action, 0);
-		g_signal_connect_object (proxy, "user_changed",
+		g_signal_connect_object (proxy, "user-changed",
 					 G_CALLBACK (user_changed_cb), action, 0);
+		g_signal_connect_object (proxy, "lock-clicked",
+					 G_CALLBACK (lock_clicked_cb), action, 0);
 		g_signal_connect_object (proxy, "get-location",
 					 G_CALLBACK (get_location_cb), action, 0);
 		g_signal_connect_object (proxy, "get-title",
@@ -403,7 +448,7 @@ ephy_location_action_set_property (GObject *object,
 	switch (prop_id)
 	{
 		case PROP_ADDRESS:
-			ephy_location_action_set_address (action, g_value_get_string (value));
+			ephy_location_action_set_address (action, g_value_get_string (value), NULL);
 			break;
 		case PROP_EDITABLE:
 			action->priv->editable = g_value_get_boolean (value);
@@ -479,6 +524,16 @@ ephy_location_action_class_init (EphyLocationActionClass *class)
 	action_class->connect_proxy = connect_proxy;
 	action_class->disconnect_proxy = disconnect_proxy;
 
+	signals[LOCK_CLICKED] = g_signal_new (
+		"lock-clicked",
+		EPHY_TYPE_LOCATION_ACTION,
+		G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (EphyLocationActionClass, lock_clicked),
+		NULL, NULL,
+		g_cclosure_marshal_VOID__VOID,
+		G_TYPE_NONE,
+		0);
+
 	g_object_class_install_property (object_class,
 					 PROP_ADDRESS,
 					 g_param_spec_string ("address",
@@ -681,6 +736,7 @@ ephy_location_action_finalize (GObject *object)
 
 	g_list_free (priv->actions);
 	g_free (priv->address);
+	g_free (priv->typed_address);
 	g_free (priv->icon);
 	g_free (priv->lock_stock_id);
 	g_free (priv->lock_tooltip);
@@ -699,13 +755,22 @@ ephy_location_action_get_address (EphyLocationAction *action)
 
 void
 ephy_location_action_set_address (EphyLocationAction *action,
-				  const char *address)
+				  const char *address,
+				  const char *typed_address)
 {
+	EphyLocationActionPrivate *priv;
+
 	g_return_if_fail (EPHY_IS_LOCATION_ACTION (action));
 
-	LOG ("set_address %s", address)
+	priv = action->priv;
+
+	LOG ("set_address %s", address);
+
+	g_free (priv->address);
+	priv->address = g_strdup (address);
+
+	g_free (priv->typed_address);
+	priv->typed_address = typed_address ? g_strdup (typed_address) : NULL;
 
-	g_free (action->priv->address);
-	action->priv->address = g_strdup (address);
 	g_object_notify (G_OBJECT (action), "address");
 }
