@@ -15,13 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-main.c,v 1.39 2005/05/11 11:30:37 chpe Exp $
+ *  $Id: ephy-main.c,v 1.41 2005/07/03 21:38:55 jframeau Exp $
  */
 
 #include "config.h"
 
 #include "ephy-shell.h"
 #include "ephy-file-helpers.h"
+#include "ephy-object-helpers.h"
 #include "ephy-state.h"
 #include "ephy-debug.h"
 #include "ephy-stock-icons.h"
@@ -135,13 +136,6 @@ shell_weak_notify (gpointer data,
 	gtk_main_quit ();
 }
 
-static gboolean
-idle_unref (GObject *object)
-{
-	g_object_unref (object);
-	return FALSE;
-}
-
 /* Copied from libnautilus/nautilus-program-choosing.c; Needed in case
  * we have no DESKTOP_STARTUP_ID (with its accompanying timestamp).
  */
@@ -180,7 +174,7 @@ slowly_and_stupidly_obtain_timestamp (Display *xdisplay)
 		XChangeProperty (xdisplay, 
 				 xwindow, atom_name,
 				 atom_type,
-				 8, PropModeReplace, name, strlen (name));
+				 8, PropModeReplace, (unsigned char *)name, strlen (name));
 	}
 	
 	XWindowEvent (xdisplay,
@@ -308,7 +302,7 @@ main (int argc, char *argv[])
 	else if (new_instance && ephy_shell)
 	{
 		g_object_weak_ref (G_OBJECT (ephy_shell), shell_weak_notify, NULL);
-		g_idle_add ((GSourceFunc) idle_unref, ephy_shell);
+		ephy_object_idle_unref (ephy_shell);
 
 		gtk_main ();
 	}
