@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: popup-commands.c,v 1.51 2005/02/26 22:01:48 chpe Exp $
+ *  $Id: popup-commands.c,v 1.52 2005/04/19 09:37:13 chpe Exp $
  */
 
 #include "config.h"
@@ -262,8 +262,6 @@ popup_cmd_save_image_as (GtkAction *action,
 			   window, TRUE, "image");
 }
 
-#define CONF_DESKTOP_BG_PICTURE "/desktop/gnome/background/picture_filename"
-#define CONF_DESKTOP_BG_TYPE "/desktop/gnome/background/picture_options"
 #define GNOME_BACKGROUND_PREFERENCES "gnome-background-properties"
 
 static void
